/**
 * An enum containing all extension permission scopes. These scopes are primarily used to restrict
 * interactions with the Netlify API (Bitballoon).
 *
 * @internal
 */
export declare enum ExtensionScope {
    /**
     * @deprecated This scope only exists for v1 extension support. It's used by v2 extensions in the
     * enable flow, but the permissions it grants are not required to enable a v2 extension.
     */
    EnableExtension = "enable",
    EnvRead = "env:read",
    EnvWrite = "env:write",
    EnvDelete = "env:delete",
    SiteRead = "site:read",
    SiteWrite = "site:write",
    UserRead = "user:read",
    UserWrite = "user:write"
}
/**
 * humanizeExtensionScope returns an object containing human-readable labels for that scope.
 *
 * @internal
 */
export declare const humanizeExtensionScope: (scope: ExtensionScope) => {
    resource: string;
    action: string;
};
/**
 * deserializeExtensionScopes transforms a serialized list of scopes into an array of
 * ExtensionScopes. Throws if the list is malformed or contains invalid scopes.
 *
 * @internal
 */
export declare const deserializeExtensionScopes: (value: string) => ExtensionScope[];
/**
 * serializeExtensionScopes serializes a list of extension scopes into a format suitable for
 * consumption by the Jigsaw API.
 *
 * @internal
 */
export declare const serializeExtensionScopes: (scopes: ExtensionScope[]) => string;
/**
 * isValidExtensionScope checks if a given value is a valid ExtensionScope.
 *
 * @internal
 */
export declare const isValidExtensionScope: (value: unknown) => value is ExtensionScope;
//# sourceMappingURL=scopes.d.ts.map